function [ results ] = Bayesian_learning( obs, noise )
%Bayesian_learning Workers' quality learning by Bayesian updating
%   Workers' quality learning by Bayesian updating. A number of observed
%   noisy signals of qualities are provided as a vector of inputs, together
%   with the variance of the noise.
%   The function returns the probability for each quality level to be the
%   right one, given the observed signals. Quality is between 0 and 1 with steps
%   of 0.01.
%
%   Author: Diego d'Andria
%   This version: February 2017

results = zeros(101, 1);
n = numel(obs);
p_num = ones(101,1);
p_den = 0;

for q=1:101
    for k=1:n
        p_num(q,1) = p_num(q,1)*normpdf(obs(k), (q-1)/100 ,noise);
    end
end

for q=1:101
    p_den = p_den+p_num(q,1);
end

for q=1:101
    results(q,1) = p_num(q,1)/p_den;
end
